This repo contains several Jupyter notebook examples on how to use FINN.
These are intended as tutorials

* `cybersecurity` is a three-part tutorial that shows how to train a simple
quantized MLP in Brevitas and deploy that with FINN. This is a good tutorial
for getting started with FINN

* `bnn-pynq` contains several tutorials that show the steps of the FINN
compiler flow for a simple MLP and convolutional net. This gives a better understanding of the FINN internals.

In addition to these notebooks, you may want to check out the [finn-examples](https://github.com/Xilinx/finn-examples) repo, which contains
several prebuilt bitfiles (including a MobileNet-v1) as well as the Python scripts to rebuild them with
FINN.
